[HarfBuzz] harfbuzz-ng: Branch 'master' - 2 commits

Behdad Esfahbod behdad at kemper.freedesktop.org
Tue Dec 14 20:51:51 PST 2010


 src/hb-open-file-private.hh |   18 +++++++++---------
 src/hb-ot-head-private.hh   |    8 +++++++-
 2 files changed, 16 insertions(+), 10 deletions(-)

New commits:
commit 22c537657cee1f47a4056a21e2cddfcbe6ab1c01
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Tue Dec 14 23:51:29 2010 -0500

    Rename TableDirectory to TableRecord as per OpenType 1.6

diff --git a/src/hb-ot-head-private.hh b/src/hb-ot-head-private.hh
index 56a5861..3a4bbbf 100644
--- a/src/hb-ot-head-private.hh
+++ b/src/hb-ot-head-private.hh
@@ -100,7 +100,13 @@ struct head
 					 *   for rendering should not be considered optimized
 					 *   for ClearType, and therefore should keep this bit
 					 *   cleared.
-					 * Bit 14: Reserved, set to 0
+					 * Bit 14: Last Resort font. If set, indicates that
+					 * the glyphs encoded in the cmap subtables are simply
+					 * generic symbolic representations of code point
+					 * ranges and don’t truly represent support for those
+					 * code points. If unset, indicates that the glyphs
+					 * encoded in the cmap subtables represent proper
+					 * support for those code points.
 					 * Bit 15: Reserved, set to 0. */
   USHORT	unitsPerEm;		/* Valid range is from 16 to 16384. This value
 					 * should be a power of 2 for fonts that have



More information about the HarfBuzz mailing list
diff --git a/src/hb-open-file-private.hh b/src/hb-open-file-private.hh
index 0782f65..cfb60db 100644
--- a/src/hb-open-file-private.hh
+++ b/src/hb-open-file-private.hh
@@ -48,7 +48,7 @@ struct OffsetTable;
 struct TTCHeader;
 
 
-typedef struct TableDirectory
+typedef struct TableRecord
 {
   inline bool sanitize (hb_sanitize_context_t *c) {
     TRACE_SANITIZE ();
@@ -70,10 +70,10 @@ typedef struct OffsetTable
 
   inline unsigned int get_table_count (void) const
   { return numTables; }
-  inline const TableDirectory& get_table (unsigned int i) const
+  inline const TableRecord& get_table (unsigned int i) const
   {
-    if (unlikely (i >= numTables)) return Null(TableDirectory);
-    return tableDir[i];
+    if (unlikely (i >= numTables)) return Null(TableRecord);
+    return tables[i];
   }
   inline bool find_table_index (hb_tag_t tag, unsigned int *table_index) const
   {
@@ -82,7 +82,7 @@ typedef struct OffsetTable
     unsigned int count = numTables;
     for (unsigned int i = 0; i < count; i++)
     {
-      if (t == tableDir[i].tag)
+      if (t == tables[i].tag)
       {
         if (table_index) *table_index = i;
         return true;
@@ -91,7 +91,7 @@ typedef struct OffsetTable
     if (table_index) *table_index = Index::NOT_FOUND_INDEX;
     return false;
   }
-  inline const TableDirectory& get_table_by_tag (hb_tag_t tag) const
+  inline const TableRecord& get_table_by_tag (hb_tag_t tag) const
   {
     unsigned int table_index;
     find_table_index (tag, &table_index);
@@ -102,7 +102,7 @@ typedef struct OffsetTable
   inline bool sanitize (hb_sanitize_context_t *c) {
     TRACE_SANITIZE ();
     return c->check_struct (this)
-	&& c->check_array (tableDir, TableDirectory::static_size, numTables);
+	&& c->check_array (tables, TableRecord::static_size, numTables);
   }
 
   private:
@@ -111,9 +111,9 @@ typedef struct OffsetTable
   USHORT	searchRange;	/* (Maximum power of 2 <= numTables) x 16 */
   USHORT	entrySelector;	/* Log2(maximum power of 2 <= numTables). */
   USHORT	rangeShift;	/* NumTables x 16-searchRange. */
-  TableDirectory tableDir[VAR];	/* TableDirectory entries. numTables items */
+  TableRecord	tables[VAR];	/* TableRecord entries. numTables items */
   public:
-  DEFINE_SIZE_ARRAY (12, tableDir);
+  DEFINE_SIZE_ARRAY (12, tables);
 } OpenTypeFontFace;
 
 
commit 33e8b86197239e667a887709104357bdc6566b7c
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Mon Dec 13 15:54:56 2010 -0500

    Update 'head' table to OpenType 1.6
